@@ -4,6 +4,7 @@ from emmet.core.eos import EOSDoc
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
+from emmet.api.core.settings import MAPISettings
 
 
 def eos_resource(eos_store):
@@ -19,6 +20,7 @@ def eos_resource(eos_store):
         header_processor=GlobalHeaderProcessor(),
         tags=["EOS"],
         disable_validation=True,
+        timeout=MAPISettings().TIMEOUT
     )
 
     return resource
